@@ -69,15 +69,18 @@ sub store_result {
 sub configure_and_spawn_mce {
 
    return MCE->new(
+
       max_workers => 7,
 
       user_func   => sub {
          my $self = $_[0];
          my $data = $self->{user_data};
          return unless (defined $data);
-         my $tam  = $data->[3];
+
+         my $tam = $data->[3];
          my $result = zeroes $tam,$tam;
          strassen_r($data->[0], $data->[1], $result, $tam);
+
          $self->do('store_result', $data->[2], $result);
       }
 
@@ -138,6 +141,9 @@ sub strassen {
    sum_m($b21, $b22, $t2, $nTam);
    $mce->send([ $t1, $t2, 7, $nTam ]);
 
+   undef $a11;             undef $a21; undef $a22;
+   undef $b11; undef $b12; undef $b21; undef $b22;
+
    $mce->run();
 
    $p1 = $p[1]; $p2 = $p[2]; $p3 = $p[3]; $p4 = $p[4];
@@ -145,6 +151,8 @@ sub strassen {
 
    calc_m($p1, $p2, $p3, $p4, $p5, $p6, $p7, $c, $nTam);
 
+   @p = ();
+
    return;
 }
 
